@@ -62,7 +62,6 @@ static svn_error_t *py_commit_callback(const svn_commit_info_t *commit_info, voi
 {
 	PyObject *fn = (PyObject *)baton, *ret;
 	PyGILState_STATE state;
-	svn_error_t *err = NULL;
 
 	if (fn == Py_None)
 		return NULL;
@@ -75,7 +74,7 @@ static svn_error_t *py_commit_callback(const svn_commit_info_t *commit_info, voi
 	CB_CHECK_PYRETVAL(ret);
 	Py_DECREF(ret);
 	PyGILState_Release(state);
-	return err;
+	return NULL;
 }
 
 static PyObject *pyify_lock(const svn_lock_t *lock)
@@ -404,7 +403,9 @@ static void ra_done_handler(void *_ra)
 	_save = PyEval_SaveThread(); \
 	err = (cmd); \
 	PyEval_RestoreThread(_save); \
-	if (!check_error(err)) { \
+	if (err != NULL) { \
+		handle_svn_error(err); \
+		svn_error_clear(err); \
 		apr_pool_destroy(pool); \
 		ra->busy = false; \
 		return NULL; \
@@ -513,7 +514,6 @@ static void py_progress_func(apr_off_t progress, apr_off_t total, void *baton, a
 	PyObject *fn = (PyObject *)ra->progress_func, *ret;
 	if (fn != Py_None) {
 		ret = PyObject_CallFunction(fn, "LL", progress, total);
-		/* TODO: What to do with exceptions raised here ? */
 		Py_XDECREF(ret);
 	}
 	PyGILState_Release(state);
@@ -548,15 +548,15 @@ static PyObject *ra_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 	ret->root = NULL;
 	ret->pool = Pool(NULL);
 	if (ret->pool == NULL) {
-        Py_DECREF(ret);
+		Py_DECREF(ret);
 		return NULL;
-    }
+	}
 
 	ret->url = svn_path_canonicalize(url, ret->pool);
-    if (ret->url == NULL) {
-        Py_DECREF(ret);
-        return NULL;
-    }
+	if (ret->url == NULL) {
+		Py_DECREF(ret);
+		return NULL;
+	}
 
 	if ((PyObject *)auth == Py_None) {
 		ret->auth = NULL;
@@ -571,7 +571,10 @@ static PyObject *ra_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 		return NULL;
 	}
 
-	if (!check_error(svn_ra_create_callbacks(&callbacks2, ret->pool))) {
+	err = svn_ra_create_callbacks(&callbacks2, ret->pool);
+	if (err != NULL) {
+		handle_svn_error(err);
+		svn_error_clear(err);
 		Py_DECREF(ret);
 		return NULL;
 	}
@@ -582,6 +585,7 @@ static PyObject *ra_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 	callbacks2->progress_func = py_progress_func;
 	callbacks2->auth_baton = auth_baton;
 	callbacks2->open_tmp_file = py_open_tmp_file;
+	callbacks2->cancel_func = py_cancel_check;
 	Py_INCREF(progress_cb);
 	ret->progress_func = progress_cb;
 	callbacks2->progress_baton = (void *)ret;
@@ -608,7 +612,9 @@ static PyObject *ra_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 			   callbacks2, ret, config_hash, ret->pool);
 #endif
 	Py_END_ALLOW_THREADS
-	if (!check_error(err)) {
+	if (err != NULL) {
+		handle_svn_error(err);
+		svn_error_clear(err);
 		Py_DECREF(ret);
 		return NULL;
 	}
@@ -889,10 +895,11 @@ static PyObject *ra_do_update(PyObject *self, PyObject *args)
 
 #endif
 	Py_END_ALLOW_THREADS
-	if (!check_error(err)) {
+	if (err != NULL) {
+		handle_svn_error(err);
+		svn_error_clear(err);
 		apr_pool_destroy(temp_pool);
 		ra->busy = false;
-
 		return NULL;
 	}
 
@@ -949,7 +956,9 @@ static PyObject *ra_do_switch(PyObject *self, PyObject *args)
 
 	Py_END_ALLOW_THREADS
 
-	if (!check_error(err)) {
+	if (err != NULL) {
+		handle_svn_error(err);
+		svn_error_clear(err);
 		apr_pool_destroy(temp_pool);
 		ra->busy = false;
 		return NULL;
@@ -1010,10 +1019,11 @@ static PyObject *ra_do_diff(PyObject *self, PyObject *args)
 												  temp_pool);
 #endif
 	Py_END_ALLOW_THREADS
-	if (!check_error(err)) {
+	if (err != NULL) {
+		handle_svn_error(err);
+		svn_error_clear(err);
 		apr_pool_destroy(temp_pool);
 		ra->busy = false;
-
 		return NULL;
 	}
 
@@ -1254,7 +1264,9 @@ static PyObject *get_commit_editor(PyObject *self, PyObject *args, PyObject *kwa
 #endif
 	Py_END_ALLOW_THREADS
 
-	if (!check_error(err)) {
+	if (err != NULL) {
+		handle_svn_error(err);
+		svn_error_clear(err);
 		apr_pool_destroy(pool);
 		ra->busy = false;
 		return NULL;
